@@ -3,7 +3,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import print_function
 
 import sys
 import re
@@ -48,7 +47,7 @@ subcommand_descriptions = {
     'upgrade':       'upgrade store format to latest version',
     'addref':        'import citation references to GF store config',
     'qc':            'quality check',
-    'report':        'report for Green\'s Function databases',
+    'report':        "report for Green's Function databases",
 }
 
 subcommand_usages = {
@@ -565,7 +564,18 @@ def command_view(args):
     except (gf.meta.GridSpecError, gf.StoreError, gf.meta.OutOfBounds) as e:
         die(e)
 
-    trace.snuffle(traces, markers=markers, opengl=options.opengl)
+    def setup(win):
+        viewer = win.get_view()
+        viewer.menuitem_showboxes.setChecked(False)
+        viewer.menuitem_colortraces.setChecked(True)
+        viewer.menuitem_demean.setChecked(False)
+        viewer.menuitems_sorting[5][0].setChecked(True)
+        viewer.menuitems_scaling[2][0].setChecked(True)
+        viewer.sortingmode_change()
+        viewer.scalingmode_change()
+
+    trace.snuffle(
+        traces, markers=markers, opengl=options.opengl, launch_hook=setup)
 
 
 def command_extract(args):
@@ -1106,7 +1116,7 @@ Browse pre-calculated Green's function stores online:
 
     parser, options, args = cl_parse(
         'download', args, setup=setup, details=details)
-    if not len(args) in (1, 2):
+    if len(args) not in (1, 2):
         sys.exit(parser.format_help())
 
     if len(args) == 2:
@@ -1335,4 +1345,4 @@ def main(args=None):
 
 
 if __name__ == '__main__':
-    main(sys.argv[1:])
+    main()
