@@ -3,7 +3,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import, division
 
 import sys
 import re
@@ -300,6 +299,10 @@ def process(get_pile, options):
 
                 traces = out_traces
 
+            if options.scale is not None:
+                for tr in traces:
+                    tr.ydata = options.scale * tr.ydata
+
             if options.output_data_type != 'same':
                 for tr in traces:
                     tr.ydata = tr.ydata.astype(
@@ -400,7 +403,7 @@ def main(args=None):
         default=config.config().cache_dir,
         metavar='DIR',
         help='use directory DIR to cache trace metadata '
-             '(default=\'%default\')')
+             "(default='%default')")
 
     parser.add_option(
         '--quiet',
@@ -440,6 +443,14 @@ def main(args=None):
         metavar='RATE',
         help='downsample to RATE [Hz]')
 
+    parser.add_option(
+        '--scale',
+        dest='scale',
+        type=float,
+        metavar='FACTOR',
+        help='scale seismograms with given FACTOR. Changes data type to '
+             'float64. Use --output-data-type to change again after scaling.')
+
     parser.add_option(
         '--output',
         dest='output_path',
@@ -452,7 +463,7 @@ def main(args=None):
              'producing many small files for gappy traces), %(wmin_year)s, '
              '%(wmin_month)s, %(wmin_day)s, %(wmin)s, %(wmin_jday)s, '
              '%(wmax_year)s, %(wmax_month)s, %(wmax_day)s, %(wmax)s, '
-             '%(wmax_jday)s. Example: --output=\'data/%s/trace-%s-%c.mseed\'')
+             "%(wmax_jday)s. Example: --output='data/%s/trace-%s-%c.mseed'")
 
     parser.add_option(
         '--output-dir',
@@ -490,8 +501,8 @@ def main(args=None):
         choices=('station-by-station', 'channel-by-channel', 'chronological'),
         default='station-by-station',
         help='set traversal order for traces processing. '
-             'Choices are \'station-by-station\' [default], '
-             '\'channel-by-channel\', and \'chronological\'. Chronological '
+             "Choices are 'station-by-station' [default], "
+             "'channel-by-channel', and 'chronological'. Chronological "
              'traversal uses more processing memory but makes it possible to '
              'join multiple stations into single output files')
 
@@ -607,4 +618,4 @@ def main(args=None):
 
 
 if __name__ == '__main__':
-    main(sys.argv[1:])
+    main()
