@@ -7,5 +7,4 @@
 from pyrocko.squirrel import main
 
 if __name__ == '__main__':
-    import sys
-    main(sys.argv)
+    main()
