@@ -41,12 +41,7 @@ struct module_state {
     PyObject *error;
 };
 
-#if PY_MAJOR_VERSION >= 3
 #define GETSTATE(m) ((struct module_state*)PyModule_GetState(m))
-#else
-#define GETSTATE(m) (&_state); (void) m;
-static struct module_state _state;
-#endif
 
 static int good_array(const PyObject* o, int typenum) {
     if (!PyArray_Check(o)) {
@@ -269,7 +264,6 @@ static PyMethodDef signal_ext_methods[] = {
     {NULL, NULL, 0, NULL}        /* Sentinel */
 };
 
-#if PY_MAJOR_VERSION >= 3
 
 static int signal_ext_traverse(PyObject *m, visitproc visit, void *arg) {
     Py_VISIT(GETSTATE(m)->error);
@@ -299,19 +293,9 @@ static struct PyModuleDef moduledef = {
 PyMODINIT_FUNC
 PyInit_signal_ext(void)
 
-#else
-#define INITERROR return
-
-void
-initsignal_ext(void)
-#endif
 
 {
-#if PY_MAJOR_VERSION >= 3
     PyObject *module = PyModule_Create(&moduledef);
-#else
-    PyObject *module = Py_InitModule("signal_ext", signal_ext_methods);
-#endif
     import_array();
 
     if (module == NULL)
@@ -327,7 +311,5 @@ initsignal_ext(void)
     Py_INCREF(st->error);
     PyModule_AddObject(module, "Error", st->error);
 
-#if PY_MAJOR_VERSION >= 3
     return module;
-#endif
 }
