@@ -2,7 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import, division
 
 import numpy as num
 import logging
@@ -215,7 +214,7 @@ class AhfullGFBuilder(gf.builder.Builder):
 
                     x = xs[tr.meta['isource']]
                     if x > firstx + (nx-1)*dx:
-                        logger.error("x out of range")
+                        logger.error('x out of range')
                         continue
 
                     ig, factor = gfmap[tr.channel]
