@@ -5,7 +5,6 @@
 '''
 Effective seismological trace viewer.
 '''
-from __future__ import absolute_import
 
 import os
 import sys
@@ -239,7 +238,7 @@ def snuffler_from_commandline(args=None):
         default=config.config().cache_dir,
         metavar='DIR',
         help='use directory DIR to cache trace metadata '
-             '(default=\'%default\')')
+             "(default='%default')")
 
     parser.add_option(
         '--force-cache',
