@@ -8,7 +8,6 @@ Snuffling infrastructure
 This module provides the base class :py:class:`Snuffling` for user-defined
 snufflings and some utilities for their handling.
 '''
-from __future__ import absolute_import
 
 import os
 import sys
@@ -265,7 +264,7 @@ class Snuffling(object):
                 'mseed', 'sac', 'kan', 'segy', 'seisan', 'seisan.l',
                 'seisan.b', 'gse1', 'gcf', 'yaff', 'datacube',
                 'from_extension', 'detect'),
-            help='assume files are of given FORMAT [default: \'%default\']')
+            help="assume files are of given FORMAT [default: '%default']")
 
         parser.add_option(
             '--pattern',
@@ -537,7 +536,7 @@ class Snuffling(object):
         scroll_area.setWidget(f)
         scroll_area.setWidgetResizable(True)
 
-        self._panel_parent.add_tab(name or "Pixmap", scroll_area)
+        self._panel_parent.add_tab(name or 'Pixmap', scroll_area)
         return f
 
     def web_frame(self, url=None, name=None):
