@@ -2,8 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-# python 2/3
-from __future__ import absolute_import
 
 import os
 import math
