@@ -83,12 +83,7 @@ struct module_state {
     PyObject *error;
 };
 
-#if PY_MAJOR_VERSION >= 3
 #define GETSTATE(m) ((struct module_state*)PyModule_GetState(m))
-#else
-#define GETSTATE(m) (&_state); (void) m;
-static struct module_state _state;
-#endif
 
 int good_array(PyObject* o, int typenum) {
     if (!PyArray_Check(o)) {
@@ -1259,8 +1254,6 @@ static PyMethodDef datacube_ext_methods[] = {
 };
 
 
-#if PY_MAJOR_VERSION >= 3
-
 static int datacube_ext_traverse(PyObject *m, visitproc visit, void *arg) {
     Py_VISIT(GETSTATE(m)->error);
     return 0;
@@ -1289,19 +1282,9 @@ static struct PyModuleDef moduledef = {
 PyMODINIT_FUNC
 PyInit_datacube_ext(void)
 
-#else
-#define INITERROR return
-
-void
-initdatacube_ext(void)
-#endif
 
 {
-#if PY_MAJOR_VERSION >= 3
     PyObject *module = PyModule_Create(&moduledef);
-#else
-    PyObject *module = Py_InitModule("datacube_ext", datacube_ext_methods);
-#endif
     import_array();
 
     if (module == NULL)
@@ -1317,7 +1300,5 @@ initdatacube_ext(void)
     Py_INCREF(st->error);
     PyModule_AddObject(module, "DataCubeError", st->error);
 
-#if PY_MAJOR_VERSION >= 3
     return module;
-#endif
 }
