@@ -2,7 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import
 
 import os
 import sys
@@ -253,7 +252,7 @@ class SeedVolumeAccess(eventdata.EventDataAccess):
         if not os.path.isfile(self.seedvolume):
             raise SeedVolumeNotFound()
 
-        self.tempdir = tempfile.mkdtemp("", "SeedVolumeAccess-")
+        self.tempdir = tempfile.mkdtemp('', 'SeedVolumeAccess-')
         self.station_headers_file = os.path.join(
             self.tempdir, 'station_header_infos')
         self._unpack()
