@@ -2,7 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import, division, print_function
 
 import sys
 import time
@@ -23,11 +22,6 @@ from pyrocko.util import hpfloat, time_to_str, get_time_float
 import pyrocko.model
 from pyrocko import util, response
 
-try:
-    newstr = unicode
-except NameError:
-    newstr = str
-
 guts_prefix = 'sx'
 
 guts_xmlns = 'http://www.fdsn.org/xml/station/1'
@@ -334,7 +328,7 @@ class DummyAwareOptionalTimestamp(Object):
                 tt = val.timetuple()
                 val = time_float(calendar.timegm(tt))
 
-            elif isinstance(val, (str, newstr)):
+            elif isinstance(val, str):
                 val = val.strip()
 
                 tz_offset = 0
@@ -1339,6 +1333,13 @@ class Response(Object):
                                          xmltagname='InstrumentPolynomial')
     stage_list = List.T(ResponseStage.T(xmltagname='Stage'))
 
+    @property
+    def output_sample_rate(self):
+        if self.stage_list:
+            return self.stage_list[-1].output_sample_rate
+        else:
+            return None
+
     def check_sample_rates(self, channel):
 
         if self.stage_list:
@@ -1487,7 +1488,7 @@ class Response(Object):
 
         elif self.instrument_sensitivity:
             raise NoResponseInformation(
-                'Only instrument sensitivity given (won\'t use it). (%s).'
+                "Only instrument sensitivity given (won't use it). (%s)."
                 % context)
         else:
             raise NoResponseInformation(
@@ -1687,7 +1688,7 @@ class Channel(BaseNode):
     sensor = Equipment.T(optional=True, xmltagname='Sensor')
     pre_amplifier = Equipment.T(optional=True, xmltagname='PreAmplifier')
     data_logger = Equipment.T(optional=True, xmltagname='DataLogger')
-    equipment = Equipment.T(optional=True, xmltagname='Equipment')
+    equipment_list = List.T(Equipment.T(xmltagname='Equipment'))
     response = Response.T(optional=True, xmltagname='Response')
 
     @property
