@@ -21,8 +21,6 @@ moment according to the "standard decomposition" can be found in the
 output of :py:meth:`MomentTensor.standard_decomposition`.
 '''
 
-from __future__ import division, print_function, absolute_import
-
 import math
 import numpy as num
 
@@ -440,9 +438,9 @@ def random_dc(x=None, scalar_moment=1.0, magnitude=None):
 
 
 def sm(m):
-    return "/ %5.2F %5.2F %5.2F \\\n" % (m[0, 0], m[0, 1], m[0, 2]) + \
-        "| %5.2F %5.2F %5.2F |\n" % (m[1, 0], m[1, 1], m[1, 2]) + \
-        "\\ %5.2F %5.2F %5.2F /\n" % (m[2, 0], m[2, 1], m[2, 2])
+    return '/ %5.2F %5.2F %5.2F \\\n' % (m[0, 0], m[0, 1], m[0, 2]) + \
+        '| %5.2F %5.2F %5.2F |\n' % (m[1, 0], m[1, 1], m[1, 2]) + \
+        '\\ %5.2F %5.2F %5.2F /\n' % (m[2, 0], m[2, 1], m[2, 2])
 
 
 def as_mt(mt):
