@@ -2,7 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import, division, print_function
 
 import os
 import logging
@@ -136,9 +135,9 @@ class Sorted(object):
         return state
 
     def __setstate__(self, state):
-        l, key = state
+        it, key = state
         self._set_key(key)
-        self._avl = avl.from_iter(iter(l), len(l))
+        self._avl = avl.from_iter(iter(it), len(it))
 
     def insert(self, value):
         self._avl.insert(value)
@@ -1285,13 +1284,13 @@ class Pile(TracesGroup):
         '''
         if tmin is None:
             if self.tmin is None:
-                logger.warning('Pile\'s tmin is not set - pile may be empty.')
+                logger.warning("Pile's tmin is not set - pile may be empty.")
                 return
             tmin = self.tmin + tpad
 
         if tmax is None:
             if self.tmax is None:
-                logger.warning('Pile\'s tmax is not set - pile may be empty.')
+                logger.warning("Pile's tmax is not set - pile may be empty.")
                 return
             tmax = self.tmax - tpad
 
