@@ -46,7 +46,6 @@ in the Pyrocko source directory)::
     plt.show()
 
 '''
-from __future__ import absolute_import
 
 import math
 import random
@@ -58,12 +57,6 @@ from pyrocko.util import parse_md, time_to_str, arange2, to_time_float
 from pyrocko.guts import StringChoice, Float, Int, Bool, Tuple, Object
 
 
-try:
-    newstr = unicode
-except NameError:
-    newstr = str
-
-
 __doc__ += parse_md(__file__)
 
 
@@ -83,7 +76,7 @@ _doc_units = "``'point'``, ``'inch'``, or ``'cm'``"
 
 
 def apply_units(x, units):
-    if isinstance(units, (str, newstr)):
+    if isinstance(units, str):
         units = units_dict[units]
 
     if isinstance(x, (int, float)):
@@ -146,7 +139,7 @@ def color(x=None):
         else:
             return (0, 0, 0)
 
-    elif isinstance(x, (str, newstr)):
+    elif isinstance(x, str):
         if x in tango_colors:
             return tango_colors[x]
 
@@ -301,7 +294,7 @@ class AutoScaler(Object):
     snap = Bool.T(
         default=False,
         help='If set to True, snap output range to multiples of increment. '
-             'This parameter has no effect, if mode is set to ``\'off\'``.')
+             "This parameter has no effect, if mode is set to ``'off'``.")
 
     inc = Float.T(
         optional=True,
@@ -312,9 +305,9 @@ class AutoScaler(Object):
         default=0.0,
         help='Add some padding to the range. The value given, is the fraction '
              'by which the output range is increased on each side. If mode is '
-             '``\'0-max\'`` or ``\'min-0\'``, the end at zero is kept fixed '
+             "``'0-max'`` or ``'min-0'``, the end at zero is kept fixed "
              'at zero. This parameter has no effect if mode is set to '
-             '``\'off\'``.')
+             "``'off'``.")
 
     exp_factor = Int.T(
         default=3,
@@ -688,11 +681,19 @@ def mpl_color(x):
     raise InvalidColorDef('invalid color definition: %s' % x)
 
 
+hours = 3600.
+days = hours*24
+approx_months = days*30.5
+approx_years = days*365
+
+
+nice_time_tinc_inc_approx_units = {
+    'seconds': 1,
+    'months': approx_months,
+    'years': approx_years}
+
+
 def nice_time_tick_inc(tinc_approx):
-    hours = 3600.
-    days = hours*24
-    approx_months = days*30.5
-    approx_years = days*365
 
     if tinc_approx >= approx_years:
         return max(1.0, nice_value(tinc_approx / approx_years)), 'years'
@@ -719,6 +720,11 @@ def nice_time_tick_inc(tinc_approx):
         return nice_value(tinc_approx), 'seconds'
 
 
+def nice_time_tick_inc_approx_secs(tinc_approx):
+    v, unit = nice_time_tick_inc(tinc_approx)
+    return v * nice_time_tinc_inc_approx_units[unit]
+
+
 def time_tick_labels(tmin, tmax, tinc, tinc_unit):
 
     if tinc_unit == 'years':
