@@ -2,7 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import, print_function
 
 import math
 import random
@@ -21,11 +20,8 @@ from pyrocko.guts_array import Array
 from pyrocko.dataset import topo
 from pyrocko import orthodrome as od
 from . import gmtpy
+from . import nice_value
 
-try:
-    newstr = unicode
-except NameError:
-    newstr = str
 
 points_in_region = od.points_in_region
 
@@ -118,7 +114,7 @@ class FloatTile(Object):
 
 class City(Object):
     def __init__(self, name, lat, lon, population=None, asciiname=None):
-        name = newstr(name)
+        name = str(name)
         lat = float(lat)
         lon = float(lon)
         if asciiname is None:
@@ -622,7 +618,7 @@ class Map(Object):
         else:
             axes_layout = self.axes_layout
 
-        scale_km = gmtpy.nice_value(self.radius/5.) / 1000.
+        scale_km = nice_value(self.radius/5.) / 1000.
 
         if self.show_center_mark:
             gmt.psxy(
