@@ -2,7 +2,6 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-from __future__ import absolute_import
 
 import math
 import numpy as num
@@ -410,7 +409,7 @@ def plot_rays(paths, rays, zstart, zstop,
 
         for zs, xs in zip(fanz, fanx):
             if phase_label in labels:
-                phase_label = ""
+                phase_label = ''
 
             axes.plot(xs, zs, color=color, label=phase_label)
             if legend:
