@@ -30,15 +30,17 @@ Example
 
     Example response plot
 '''
-from __future__ import absolute_import
 
 import logging
 import math
+import hashlib
+from io import BytesIO
 
 import numpy as num
 
 from pyrocko import util
 from pyrocko import guts
+from pyrocko.response import InvalidResponseError
 
 
 logger = logging.getLogger('plot.response')
@@ -57,7 +59,9 @@ def draw(
         normalize=False,
         style={},
         label=None,
-        show_breakpoints=False):
+        show_breakpoints=False,
+        color_pool=None,
+        label_pool=None):
 
     '''
     Draw instrument response in Bode plot style to given Matplotlib axes
@@ -105,8 +109,33 @@ def draw(
 
     ta = num.abs(tf)
 
+    if color_pool is not None:
+        fh = BytesIO()
+        f.dump(fh)
+        tf.dump(fh)
+        c_key = hashlib.sha1(fh.getvalue()).hexdigest()
+        fh.close()
+        if c_key not in color_pool[0]:
+            color_pool[0][c_key] \
+                = color_pool[1][len(color_pool[0]) % len(color_pool[1])]
+            new = True
+        else:
+            new = False
+
+        style = dict(style)
+        style['color'] = color_pool[0][c_key]
+
+        ikey = list(color_pool[0].keys()).index(c_key) + 1
+        slabel = '[%i]' % ikey
+
+        if label_pool is not None:
+            label_pool.append('%s %s' % (slabel, label))
+            eff_label = slabel if new else None
+        else:
+            eff_label = '%s %s' % (slabel, label)
+
     if axes_amplitude:
-        axes_amplitude.plot(f, ta, label=label, **style)
+        axes_amplitude.plot(f, ta, label=eff_label, **style)
         for checkpoint in response.checkpoints:
             axes_amplitude.plot(
                 checkpoint.frequency, checkpoint.value, 'o',
@@ -148,7 +177,7 @@ def draw(
         tp = num.unwrap(num.angle(tf))
         ioff = int(num.round(tp[iflat] / (2.0*num.pi)))
         tp -= ioff * 2.0 * num.pi
-        axes_phase.plot(f, tp/num.pi, label=label, **style)
+        axes_phase.plot(f, tp/num.pi, label=eff_label, **style)
     else:
         tp = [0.]
 
@@ -190,7 +219,8 @@ def plot(
         figsize=None,
         styles=None,
         labels=None,
-        show_breakpoints=False):
+        show_breakpoints=False,
+        separate_combined_labels=None):
 
     '''
     Draw instrument responses in Bode plot style.
@@ -234,12 +264,18 @@ def plot(
     setup_axes(axes_amplitude, axes_phase)
 
     if styles is None:
-        styles = [
-            dict(color=to01(graph_colors[i % len(graph_colors)]))
-            for i in range(len(responses))]
+        styles = [{} for i in range(len(responses))]
+        color_pool = ({}, [to01(color) for color in graph_colors])
+
     else:
+        color_pool = None
         assert len(styles) == len(responses)
 
+    if separate_combined_labels is not None:
+        label_pool = []
+    else:
+        label_pool = None
+
     if labels is None:
         labels = [None] * len(responses)
     else:
@@ -248,25 +284,36 @@ def plot(
     a_ranges, p_ranges = [], []
     have_labels = False
     for style, resp, label in zip(styles, responses, labels):
-        a_range, p_range = draw(
-            response=resp,
-            axes_amplitude=axes_amplitude,
-            axes_phase=axes_phase,
-            fmin=fmin, fmax=fmax, nf=nf,
-            normalize=normalize,
-            style=style,
-            label=label,
-            show_breakpoints=show_breakpoints)
+        try:
+            a_range, p_range = draw(
+                response=resp,
+                axes_amplitude=axes_amplitude,
+                axes_phase=axes_phase,
+                fmin=fmin, fmax=fmax, nf=nf,
+                normalize=normalize,
+                style=style,
+                label=label,
+                show_breakpoints=show_breakpoints,
+                color_pool=color_pool,
+                label_pool=label_pool)
 
-        if label is not None:
-            have_labels = True
+            if label is not None:
+                have_labels = True
 
-        a_ranges.append(a_range)
-        p_ranges.append(p_range)
+            a_ranges.append(a_range)
+            p_ranges.append(p_range)
+
+        except InvalidResponseError as e:
+            logger.error(
+                'Error occured for response labeled "%s": %s' % (label, e))
 
     if have_labels:
         axes_amplitude.legend(loc='lower right', prop=dict(size=fontsize))
 
+    if separate_combined_labels == 'print':
+        for label in label_pool:
+            print(label)
+
     if a_ranges:
         a_ranges = num.array(a_ranges)
         p_ranges = num.array(p_ranges)
@@ -293,6 +340,9 @@ def plot(
     else:
         plt.show()
 
+    if separate_combined_labels == 'return':
+        return label_pool
+
 
 def tts(t):
     if t is None:
@@ -303,7 +353,9 @@ def tts(t):
 
 def load_response_information(
         filename, format,
-        nslc_patterns=None, fake_input_units=None, stages=None):
+        nslc_patterns=None,
+        fake_input_units=None,
+        stages=None):
 
     from pyrocko import pz, trace
     from pyrocko.io import resp as fresp
@@ -505,6 +557,15 @@ if __name__ == '__main__':
         default=False,
         help='show breakpoints of pole-zero responses')
 
+    parser.add_option(
+        '--index-labels',
+        dest='index_labels',
+        action='store_true',
+        default=False,
+        help='label graphs only by index and print details to terminal '
+             'to save space when many labels would be shown. Aggregate '
+             'identical responses under a common index.')
+
     (options, args) = parser.parse_args(sys.argv[1:])
 
     if len(args) == 0:
@@ -541,4 +602,5 @@ if __name__ == '__main__':
         fmin=options.fmin, fmax=options.fmax, nf=200,
         normalize=options.normalize,
         labels=labels, filename=options.filename, dpi=options.dpi,
-        show_breakpoints=options.show_breakpoints)
+        show_breakpoints=options.show_breakpoints,
+        separate_combined_labels='print' if options.index_labels else None)
