@@ -3,8 +3,6 @@
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
 
-from __future__ import absolute_import, print_function
-
 import time
 import os
 import copy
@@ -96,7 +94,7 @@ class MSeedArchive(Archive):
         '%(tmin_month)s',
         '%(tmin_day)s',
         'trace_%(network)s_%(station)s_%(location)s_%(channel)s'
-        + '_%(tmin_us)s_%(tmax_us)s.mseed'))
+        + '_%(block_tmin_us)s_%(block_tmax_us)s.mseed'))
 
     def __init__(self, **kwargs):
         Archive.__init__(self, **kwargs)
@@ -105,9 +103,12 @@ class MSeedArchive(Archive):
     def set_base_path(self, path):
         self._base_path = path
 
-    def add(self, trs):
+    def add(self, order, trs):
         path = op.join(self._base_path, self.template)
-        return io.save(trs, path, overwrite=True)
+        fmt = '%Y-%m-%d_%H-%M-%S.6FRAC'
+        return io.save(trs, path, overwrite=True, additional=dict(
+            block_tmin_us=util.time_to_str(order.tmin, format=fmt),
+            block_tmax_us=util.time_to_str(order.tmax, format=fmt)))
 
 
 def combine_selections(selection):
@@ -136,7 +137,9 @@ def orders_to_selection(orders):
     selection = []
     for order in sorted(orders, key=orders_sort_key):
         selection.append(
-            order.codes.nslc + (order.tmin, order.tmax))
+            order.codes.nslc + (
+                order.tmin-1.0*order.deltat,
+                order.tmax+1.0*order.deltat))
 
     return combine_selections(selection)
 
@@ -246,7 +249,7 @@ class FDSNSource(Source, has_paths.HasPaths):
         optional=True,
         help='Directory path where any downloaded waveforms and station '
              'meta-data are to be kept. By default the Squirrel '
-             'environment\'s cache directory is used.')
+             "environment's cache directory is used.")
 
     shared_waveforms = Bool.T(
         default=False,
@@ -565,6 +568,11 @@ class FDSNSource(Source, has_paths.HasPaths):
                 subnut = clone(nut)
                 subnut.tmin = tmin
                 subnut.tmax = tmax
+
+                # ignore 1-sample gaps produced by rounding errors
+                if subnut.tmax - subnut.tmin < 2*subnut.deltat:
+                    continue
+
                 yield subnut
 
         def wanted(nuts):
@@ -677,7 +685,15 @@ class FDSNSource(Source, has_paths.HasPaths):
                             elog.append(now, order, *err_this)
                             error_permanent(order)
                         else:
-                            if len(trs_order) != 1:
+                            def tsame(ta, tb):
+                                return abs(tb - ta) < 2 * order.deltat
+
+                            if len(trs_order) != 1 \
+                                    or not tsame(
+                                        trs_order[0].tmin, order.tmin) \
+                                    or not tsame(
+                                        trs_order[0].tmax, order.tmax):
+
                                 if err_this:
                                     elog.append(
                                         now, order,
@@ -686,7 +702,7 @@ class FDSNSource(Source, has_paths.HasPaths):
                                 else:
                                     elog.append(now, order, 'partial result')
 
-                            paths = self._archive.add(trs_order)
+                            paths = self._archive.add(order, trs_order)
                             all_paths.extend(paths)
 
                             nsuccess += 1
@@ -705,9 +721,12 @@ class FDSNSource(Source, has_paths.HasPaths):
                         error_temporary(order)
 
             emessage = elog.summarize_recent()
+
             self._log_info_data(
-                '%i download%s successful' % (
-                    nsuccess, util.plural_s(nsuccess))
+                '%i download%s %ssuccessful' % (
+                    nsuccess,
+                    util.plural_s(nsuccess),
+                    '(partially) ' if emessage else '')
                 + (', %s' % emessage if emessage else ''))
 
             if all_paths:
