@@ -16,8 +16,6 @@ Further content types are defined here to handle waveform orders, waveform
 promises, data coverage and sensor information.
 '''
 
-from __future__ import absolute_import, print_function
-
 import re
 import fnmatch
 import math
@@ -170,7 +168,7 @@ class CodesNSLCE(CodesNSLCEBase, Codes):
 
     @property
     def nslce(self):
-        return self[:4]
+        return self[:5]
 
     @property
     def nslc(self):
@@ -184,6 +182,14 @@ class CodesNSLCE(CodesNSLCEBase, Codes):
     def ns(self):
         return self[:2]
 
+    @property
+    def codes_nsl(self):
+        return CodesNSL(self)
+
+    @property
+    def codes_nsl_star(self):
+        return CodesNSL(self.network, self.station, '*')
+
     def as_tuple(self):
         return tuple(self)
 
@@ -651,11 +657,14 @@ class ChannelBase(Location):
     def time_span(self):
         return (self.tmin, self.tmax)
 
+    def _get_sensor_codes(self):
+        return self.codes.replace(
+            channel=self.codes.channel[:-1] + '?')
+
     def _get_sensor_args(self):
         def getattr_rep(k):
             if k == 'codes':
-                return self.codes.replace(
-                    channel=self.codes.channel[:-1] + '?')
+                return self._get_sensor_codes()
             else:
                 return getattr(self, k)
 
@@ -724,26 +733,29 @@ def cut_intervals(channels):
 
     times = sorted(times)
 
-    if len(times) < 2:
+    if any(channel.tmin is None for channel in channels):
+        times[0:0] = [None]
+
+    if any(channel.tmax is None for channel in channels):
+        times.append(None)
+
+    if len(times) <= 2:
         return channels
 
     channels_out = []
     for channel in channels:
-        tstart = channel.tmin
-        for t in times:
-            if (channel.tmin is None or channel.tmin < t) \
-                    and (channel.tmax is None or t < channel.tmax):
+        for i in range(len(times)-1):
+            tmin = times[i]
+            tmax = times[i+1]
+            if ((channel.tmin is None or (
+                    tmin is not None and channel.tmin <= tmin))
+                    and (channel.tmax is None or (
+                        tmax is not None and tmax <= channel.tmax))):
 
                 channel_out = clone(channel)
-                channel_out.tmin = tstart
-                channel_out.tmax = t
+                channel_out.tmin = tmin
+                channel_out.tmax = tmax
                 channels_out.append(channel_out)
-                tstart = t
-
-        if channel.tmax is None:
-            channel_out = clone(channel)
-            channel_out.tmin = tstart
-            channels_out.append(channel_out)
 
     return channels_out
 
@@ -757,10 +769,16 @@ class Sensor(ChannelBase):
 
     @classmethod
     def from_channels(cls, channels):
-        channels = cut_intervals(channels)
-
         groups = defaultdict(list)
         for channel in channels:
+            groups[channel._get_sensor_codes()].append(channel)
+
+        channels_cut = []
+        for group in groups.values():
+            channels_cut.extend(cut_intervals(group))
+
+        groups = defaultdict(list)
+        for channel in channels_cut:
             groups[channel._get_sensor_args()].append(channel)
 
         return [
@@ -875,9 +893,9 @@ class ResponseStage(Object):
                 and self.output_quantity == 'counts':
             return 'digitizer'
 
-        elif self.input_quantity == 'counts' \
-                and self.output_quantity == 'counts' \
-                and self.input_sample_rate != self.output_sample_rate:
+        elif self.decimation_factor is not None \
+                and (self.input_quantity is None or self.input_quantity == 'counts') \
+                and (self.output_quantity is None or self.output_quantity == 'counts'):  # noqa
             return 'decimation'
 
         elif self.input_quantity in observational_quantities \
@@ -888,20 +906,67 @@ class ResponseStage(Object):
             return 'unknown'
 
     @property
-    def summary(self):
+    def decimation_factor(self):
         irate = self.input_sample_rate
         orate = self.output_sample_rate
-        factor = None
-        if irate and orate:
-            factor = irate / orate
-        return 'ResponseStage, ' + (
-            '%s%s => %s%s%s' % (
-                self.input_quantity or '?',
-                ' @ %g Hz' % irate if irate else '',
-                self.output_quantity or '?',
-                ' @ %g Hz' % orate if orate else '',
-                ' :%g' % factor if factor else '')
-        )
+        if irate is not None and orate is not None \
+                and irate > orate and irate / orate > 1.0:
+
+            return irate / orate
+        else:
+            return None
+
+    @property
+    def summary_quantities(self):
+        return '%s -> %s' % (
+            self.input_quantity or '?',
+            self.output_quantity or '?')
+
+    @property
+    def summary_rates(self):
+        irate = self.input_sample_rate
+        orate = self.output_sample_rate
+        factor = self.decimation_factor
+
+        if irate and orate is None:
+            return '%g Hz' % irate
+
+        elif orate and irate is None:
+            return '%g Hz' % orate
+
+        elif irate and orate and irate == orate:
+            return '%g Hz' % irate
+
+        elif any(x for x in (irate, orate, factor)):
+            return '%s -> %s Hz (%s)' % (
+                '%g' % irate if irate else '?',
+                '%g' % orate if orate else '?',
+                ':%g' % factor if factor else '?')
+        else:
+            return ''
+
+    @property
+    def summary_elements(self):
+        xs = [x.summary for x in self.elements]
+        return '%s' % ('*'.join(x for x in xs if x != 'one') or 'one')
+
+    @property
+    def summary_log(self):
+        return ''.join(sorted(set(x[0][0].upper() for x in self.log)))
+
+    @property
+    def summary_entries(self):
+        return (
+            self.__class__.__name__,
+            self.stage_type,
+            self.summary_log,
+            self.summary_quantities,
+            self.summary_rates,
+            self.summary_elements)
+
+    @property
+    def summary(self):
+        return util.fmt_summary(self.summary_entries, (10, 15, 3, 30, 30, 0))
 
     def get_effective(self):
         return MultiplyResponse(responses=list(self.elements))
@@ -969,14 +1034,14 @@ class Response(Object):
 
     @property
     def output_quantity(self):
-        return self.stages[-1].input_quantity if self.stages else None
+        return self.stages[-1].output_quantity if self.stages else None
 
     @property
     def output_sample_rate(self):
         return self.stages[-1].output_sample_rate if self.stages else None
 
     @property
-    def stages_summary(self):
+    def summary_stages(self):
         def grouped(xs):
             xs = list(xs)
             g = []
@@ -994,27 +1059,49 @@ class Response(Object):
             for g in grouped(stage.stage_type for stage in self.stages))
 
     @property
-    def summary(self):
+    def summary_quantities(self):
         orate = self.output_sample_rate
-        return '%s %-16s %s' % (
-            self.__class__.__name__, self.str_codes, self.str_time_span) \
-            + ', ' + ', '.join((
-                '%s => %s' % (
-                    self.input_quantity or '?', self.output_quantity or '?')
-                + (' @ %g Hz' % orate if orate else ''),
-                self.stages_summary,
-            ))
+        return '%s -> %s%s' % (
+            self.input_quantity or '?',
+            self.output_quantity or '?',
+            ' @ %g Hz' % orate if orate else '')
 
-    def get_effective(self, input_quantity=None):
+    @property
+    def summary_log(self):
+        return ''.join(sorted(set(x[0][0].upper() for x in self.log)))
+
+    @property
+    def summary_entries(self):
+        return (
+            self.__class__.__name__,
+            str(self.codes),
+            self.str_time_span,
+            self.summary_log,
+            self.summary_quantities,
+            self.summary_stages)
+
+    @property
+    def summary(self):
+        return util.fmt_summary(self.summary_entries, (10, 20, 55, 3, 35, 0))
+
+    def get_effective(self, input_quantity=None, stages=(None, None)):
         try:
             elements = response_converters(input_quantity, self.input_quantity)
         except ConversionError as e:
             raise ConversionError(str(e) + ' (%s)' % self.summary)
 
         elements.extend(
-            stage.get_effective() for stage in self.stages)
+            stage.get_effective() for stage in self.stages[slice(*stages)])
 
-        return MultiplyResponse(responses=simplify_responses(elements))
+        if input_quantity is None \
+                or input_quantity == self.input_quantity:
+            checkpoints = self.checkpoints
+        else:
+            checkpoints = []
+
+        return MultiplyResponse(
+            responses=simplify_responses(elements),
+            checkpoints=checkpoints)
 
 
 @squirrel_content
@@ -1391,7 +1478,7 @@ class Nut(Object):
         return DummyTrace(self)
 
     @property
-    def summary(self):
+    def summary_entries(self):
         if self.tmin == self.tmax:
             ts = util.time_to_str(self.tmin)
         else:
@@ -1399,10 +1486,15 @@ class Nut(Object):
                 util.time_to_str(self.tmin),
                 util.time_to_str(self.tmax))
 
-        return ' '.join((
-            ('%s,' % to_kind(self.kind_id)).ljust(9),
-            ('%s,' % str(self.codes)).ljust(18),
-            ts))
+        return (
+            self.__class__.__name__,
+            to_kind(self.kind_id),
+            str(self.codes),
+            ts)
+
+    @property
+    def summary(self):
+        return util.fmt_summary(self.summary_entries, (10, 16, 20, 0))
 
 
 def make_waveform_nut(**kwargs):
@@ -1550,20 +1642,29 @@ class Coverage(Object):
             changes=changes)
 
     @property
-    def summary(self):
-        ts = '%s - %s,' % (
+    def summary_entries(self):
+        ts = '%s - %s' % (
             util.time_to_str(self.tmin),
             util.time_to_str(self.tmax))
 
         srate = self.sample_rate
 
-        return ' '.join((
-            ('%s,' % to_kind(self.kind_id)).ljust(9),
-            ('%s,' % str(self.codes)).ljust(18),
+        total = self.total
+
+        return (
+            self.__class__.__name__,
+            to_kind(self.kind_id),
+            str(self.codes),
             ts,
-            '%10.3g,' % srate if srate else '',
-            '%4i' % len(self.changes),
-            '%s' % duration_to_str(self.total)))
+            '%10.3g' % srate if srate else '',
+            '%i' % len(self.changes),
+            '%s' % duration_to_str(total) if total else 'none')
+
+    @property
+    def summary(self):
+        return util.fmt_summary(
+            self.summary_entries,
+            (10, 16, 20, 55, 10, 4, 0))
 
     @property
     def sample_rate(self):
@@ -1599,6 +1700,49 @@ class Coverage(Object):
 
             last = (t, count)
 
+    def iter_uncovered_by(self, other):
+        a = self
+        b = other
+        ia = ib = -1
+        ca = cb = 0
+        last = None
+        while not (ib + 1 == len(b.changes) and ia + 1 == len(a.changes)):
+            if ib + 1 == len(b.changes):
+                ia += 1
+                t, ca = a.changes[ia]
+            elif ia + 1 == len(a.changes):
+                ib += 1
+                t, cb = b.changes[ib]
+            elif a.changes[ia+1][0] < b.changes[ib+1][0]:
+                ia += 1
+                t, ca = a.changes[ia]
+            else:
+                ib += 1
+                t, cb = b.changes[ib]
+
+            if last is not None:
+                tl, cal, cbl = last
+                if tl < t and cal > 0 and cbl == 0:
+                    yield tl, t, ia, ib
+
+            last = (t, ca, cb)
+
+    def iter_uncovered_by_combined(self, other):
+        ib_last = None
+        group = None
+        for tmin, tmax, _, ib in self.iter_uncovered_by(other):
+            if ib_last is None or ib != ib_last:
+                if group:
+                    yield (group[0][0], group[-1][1])
+
+                group = []
+
+            group.append((tmin, tmax))
+            ib_last = ib
+
+        if group:
+            yield (group[0][0], group[-1][1])
+
 
 __all__ = [
     'to_codes',
