@@ -1,5 +1,4 @@
 # http://pyrocko.org - GPLv3
-
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
@@ -61,8 +60,6 @@ Module content
 ..............
 '''
 
-from __future__ import division, print_function
-
 import time
 import logging
 import os
@@ -85,16 +82,11 @@ import pyrocko
 from pyrocko import dummy_progressbar
 
 
-try:
-    from urllib.parse import urlencode, quote, unquote  # noqa
-    from urllib.request import (
-        Request, build_opener, HTTPDigestAuthHandler, urlopen as _urlopen)  # noqa
-    from urllib.error import HTTPError, URLError  # noqa
+from urllib.parse import urlencode, quote, unquote  # noqa
+from urllib.request import Request, build_opener, HTTPDigestAuthHandler  # noqa
+from urllib.request import urlopen as _urlopen  # noqa
+from urllib.error import HTTPError, URLError  # noqa
 
-except ImportError:
-    from urllib import urlencode, quote, unquote # noqa
-    from urllib2 import (Request, build_opener, HTTPDigestAuthHandler,   # noqa
-                         HTTPError, URLError, urlopen as _urlopen)  # noqa
 
 try:
     import certifi
@@ -114,7 +106,7 @@ class URLErrorSSL(URLError):
             'Requesting web resource failed and the problem could be '
             'related to SSL. Python standard libraries on some older '
             'systems (like Ubuntu 14.04) are known to have trouble '
-            'with some SSL setups of today\'s servers: %s'
+            "with some SSL setups of today's servers: %s"
             % URLError.__str__(self))
 
 
@@ -379,7 +371,7 @@ def _download(url, fpath, username=None, password=None,
                 download_file(url, fpath)
 
     except req_HTTPError as e:
-        logging.warning("http error: %s" % e)
+        logging.warning('http error: %s' % e)
         raise DownloadError('could not download file(s) from: %s' % url)
 
     finally:
@@ -576,7 +568,7 @@ def check_time_class(t, error='raise'):
     if not isinstance(t, get_time_float()):
         message = (
             'Timestamp %g is of type %s but should be of type %s with '
-            'Pyrocko\'s currently selected time handling mode.\n\n'
+            "Pyrocko's currently selected time handling mode.\n\n"
             'See https://pyrocko.org/docs/current/library/reference/util.html'
             '#high-precision-time-handling-mode' % (
                 t, type(t), get_time_float()))
@@ -692,7 +684,7 @@ class BetterHelpFormatter(optparse.IndentedHelpFormatter):
         help_text_width = self.width - help_text_position
 
         opts = self.option_strings[option]
-        opts = "%*s%s" % (self.current_indent, "", opts)
+        opts = '%*s%s' % (self.current_indent, '', opts)
         if option.help:
             help_text = self.expand_default(option)
 
@@ -707,11 +699,11 @@ class BetterHelpFormatter(optparse.IndentedHelpFormatter):
             lines.append('')
             if option.help:
                 help_lines = wrap(help_text, help_text_width)
-                lines.extend(["%*s%s" % (help_text_position, "", line)
+                lines.extend(['%*s%s' % (help_text_position, '', line)
                               for line in help_lines])
             lines.append('')
 
-        return "\n".join(lines)
+        return '\n'.join(lines)
 
     def format_description(self, description):
         if not description:
@@ -1435,7 +1427,7 @@ def decitab(n):
     return GlobalVars.decitab[n]
 
 
-def ctimegm(s, format="%Y-%m-%d %H:%M:%S"):
+def ctimegm(s, format='%Y-%m-%d %H:%M:%S'):
     '''
     Convert string representing UTC time to system time.
 
@@ -1453,7 +1445,7 @@ def ctimegm(s, format="%Y-%m-%d %H:%M:%S"):
     return calendar.timegm(time.strptime(s, format))
 
 
-def gmctime(t, format="%Y-%m-%d %H:%M:%S"):
+def gmctime(t, format='%Y-%m-%d %H:%M:%S'):
     '''
     Get string representation from system time, UTC.
 
@@ -1466,7 +1458,7 @@ def gmctime(t, format="%Y-%m-%d %H:%M:%S"):
     return time.strftime(format, time.gmtime(t))
 
 
-def gmctime_v(t, format="%a, %d %b %Y %H:%M:%S"):
+def gmctime_v(t, format='%a, %d %b %Y %H:%M:%S'):
     '''
     Get string representation from system time, UTC. Same as
     :py:func:`gmctime` but with a more verbose default format.
@@ -1478,7 +1470,7 @@ def gmctime_v(t, format="%a, %d %b %Y %H:%M:%S"):
     return time.strftime(format, time.gmtime(t))
 
 
-def gmctime_fn(t, format="%Y-%m-%d_%H-%M-%S"):
+def gmctime_fn(t, format='%Y-%m-%d_%H-%M-%S'):
     '''
     Get string representation from system time, UTC. Same as
     :py:func:`gmctime` but with a default usable in filenames.
@@ -2090,25 +2082,27 @@ def create_lockfile(fn, timeout=None, timewarn=10.):
             return
 
         except OSError as e:
-            if e.errno == errno.EEXIST:
-                tnow = time.time()
-
-                if timeout is not None and tnow - t0 > timeout:
-                    raise Timeout(
-                        'Timeout (%gs) occured while waiting to get exclusive '
-                        'access to: %s' % (timeout, fn))
-
-                if timewarn is not None and tnow - t0 > timewarn:
-                    logger.warning(
-                        'Waiting since %gs to get exclusive access to: %s' % (
-                            timewarn, fn))
-
-                    timewarn *= 2
-
-                time.sleep(0.01)
+            if e.errno in (errno.EEXIST, 13):   # 13 occurs on windows
+                pass  # retry
             else:
                 raise
 
+        tnow = time.time()
+
+        if timeout is not None and tnow - t0 > timeout:
+            raise Timeout(
+                'Timeout (%gs) occured while waiting to get exclusive '
+                'access to: %s' % (timeout, fn))
+
+        if timewarn is not None and tnow - t0 > timewarn:
+            logger.warning(
+                'Waiting since %gs to get exclusive access to: %s' % (
+                    timewarn, fn))
+
+            timewarn *= 2
+
+        time.sleep(0.01)
+
 
 def delete_lockfile(fn):
     os.unlink(fn)
@@ -2221,7 +2215,7 @@ re_escapequotes = re.compile(r"(['\\])")
 
 
 def escapequotes(s):
-    return re_escapequotes.sub(r"\\\1", s)
+    return re_escapequotes.sub(r'\\\1', s)
 
 
 class TableWriter(object):
@@ -2867,3 +2861,8 @@ def get_threadpool_limits():
 
     except ImportError:
         return threadpool_limits_dummy
+
+
+def fmt_summary(entries, widths):
+    return ' | '.join(
+        entry.ljust(width) for (entry, width) in zip(entries, widths))
